==> otu-5000-23.14.tar: etc/rc5.d/S15otu_service.sh <==
#!/bin/bash
#
# Prepare fs for Otu
#
# This script manage :
#   - /otu directory creation or deletion
#   - Debug mode for not switching part if otu doesn't start properly
#   - Symlink for Otu.ver to /acterna/release/bin/
#   - Ensure ot trusted user are removed in enhanced security mode
#   - Ensure smartotu log file are writable from apache
#

source /usr/lib/otu_functions
source /etc/profile.d/40_otu_platform.sh
source /etc/otu/otuparts.sh

inspect_repair_unused_prtn() {
    #
    #  fsck error codes 4, 8, 12 and 128 indicate a corrupted partition
    EC_CODE_4=4
    EC_CODE_8=8
    EC_CODE_12=12
    EC_CODE_128=128
    
    #
    #  Use fsck to inspect partition
    #  Options -f -n runs a check without running repairs.
    #  Recover only for fsck error codes "4" and "128"
    umount "$ALT_PART" 2>/dev/null
    res_scan_check=$(fsck -f -n -M "$ALT_PART")
    fsck_rc=$?
    otu_log $0 "Checking $ALT_PART ::  fsck error code = $fsck_rc ."

    case $fsck_rc in
        $EC_CODE_4 | $EC_CODE_8 | $EC_CODE_12 | $EC_CODE_128)
            #
            #  Unused partion is not sane.
            #  Recover device partition within capabilities of fsck.
            #
            otu_log $0 "Device $ALT_PART contains partition errors :: Initiating fsck recovery."
	          fsck -f -y $ALT_PART
            if [[ $? -eq 0 || $? -eq 1 ]]; then
                mount $ALT_PART /mnt/fs/unused_part  2>/dev/null
	              otu_log $0 "Recovery complete for device $ALT_PART ::  fsck repair return code = $?"
            else
	              otu_log $0 "Unable to repair $ALT_PART ::  fsck repair return code = $? ::  $ALT_PART is not mounted."
            fi
	      ;;

        *)
            #
            # Recovery procedure is not necessary
            #
            otu_log $0 "Partition recovery is NOT required for device $ALT_PART ."
        ;;
        esac
}

# If we are not Otu but /otu directory exists remove it (otu5000 to eotdrv2 conversion by manufacturing)
is_cotu_hw
HW_OTU=$?
is_otu_sw
SW_OTU=$?
[ "${HW_OTU}" == "0" ] && [ "${SW_OTU}" == "0" ] && [ -f /otu ] && rm -rf /otu

# Do the rest only if using otu
quit_if_not_using_otu

#
#  In OTU rescue mode only, check if unused partition
#  is corrupted and recover if possible.
#
if [[ "$(is_rescue)" == "yes" ]]; then
    otu_log $0 " . OTU is in rescue mode; inspecting $unused_prtn_device if partition is sane."
    inspect_repair_unused_prtn
fi
#

# Create /Otu directory
if [ ! -L /otu ] ;  then
    if [ -d /user/harddisk ] ; then
		mkdir -p /user/harddisk/otu
        ln -s /user/harddisk/otu /otu        
    elif [ -d /user/disk ] && [ "${HW_OTU}" == "0" ] && [ "${SW_OTU}" == "1" ] ; then
		mkdir -p /user/disk/otu
        ln -s /user/disk/otu /otu
    fi
else
	# Enforce link to otu to the harddisk if present
	if [ -d /user/harddisk ] && [ "$(readlink /otu)" != /user/harddisk/otu ] ; then
        rm /otu
        mkdir -p /user/harddisk/otu
        ln -sf /user/harddisk/otu /otu
	fi
	# Enforce /otu removal if harddisk is not present with otu hardware (do not work using flash)
	mountpoint /user/harddisk > /dev/null 2>&1
	HAS_NO_HARDDISK=$?
	if [ "${HAS_NO_HARDDISK}" == "1" ]  && [ "${HW_OTU}" == "1" ] && [ -h /otu ] ; then
	     rm -rf /otu
	fi
fi

# If the file debug exists we don't want to switch partition if Otu doesn't start
[ -f /acterna/storage/otu/debug ] && ! [ -f /otu/release/tmp/first_boot_after_upgrade.tmp ] && otu_confirm_start.sh

# if there is a otu.ver file move it to /etc/acterna/
if [ -f /acterna/release/bin/Otu.ver ] && [ ! -h /acterna/release/bin/Otu.ver ] ; then
	mv /acterna/release/bin/Otu.ver /etc/acterna/Otu.ver
fi

# Create symlink to Otu.ver file if doesn't exist
if [ ! -f /acterna/release/bin/Otu.ver ] && [ -f /etc/acterna/Otu.ver ] ; then
	ln -sf /etc/acterna/Otu.ver /acterna/release/bin/Otu.ver
fi

# In enhance security mode we have to check every boot that users have not been added during an upgrade
if [ "$(fw_printenv -n Enhanced_Security)" = "true" ] ; then
    bash /usr/lib/jdsu/scripts/update_user_list.sh "DEL" > /dev/null 2>&1
fi

# Log partition we are using in otu log
if [ -d /otu/log ] ; then
    CURRENT_DATE=$(date '+%Y-%m-%d %H:%M:%S.%3N')
    echo "${CURRENT_DATE} : Boot using partition ${CURRENT_PART}" >> /otu/log/boot.log
    if [[ "$(is_rescue)" == "yes" ]] ; then
        echo "${CURRENT_DATE} : Started in rescue mode" >> /otu/log/boot.log
    fi
fi

# Temporary : Create log file required for smartotu
touch /var/log/otu_query.log
touch /var/log/smart_otu.log
chown www-data:www-data /var/log/otu_query.log
chown www-data:www-data /var/log/smart_otu.log

exit 0

==> otu-5000-24.1006.tar: etc/rc5.d/S15otu_service.sh <==
#!/bin/bash
#
# Prepare fs for Otu
#
# This script manage :
#   - /otu directory creation or deletion
#   - Debug mode for not switching part if otu doesn't start properly
#   - Symlink for Otu.ver to /acterna/release/bin/
#   - Ensure ot trusted user are removed in enhanced security mode
#   - Ensure smartotu log file are writable from apache
#

source /usr/lib/otu_functions
source /etc/profile.d/40_otu_platform.sh
source /etc/otu/otuparts.sh

inspect_repair_unused_prtn() {
    #
    #  fsck error codes 4, 8, 12 and 128 indicate a corrupted partition
    EC_CODE_4=4
    EC_CODE_8=8
    EC_CODE_12=12
    EC_CODE_128=128
    
    #
    #  Use fsck to inspect partition
    #  Options -f -n runs a check without running repairs.
    #  Recover only for fsck error codes "4" and "128"
    umount "$ALT_PART" 2>/dev/null
    res_scan_check=$(fsck -f -n -M "$ALT_PART")
    fsck_rc=$?
    otu_log $0 "Checking $ALT_PART ::  fsck error code = $fsck_rc ."

    case $fsck_rc in
        $EC_CODE_4 | $EC_CODE_8 | $EC_CODE_12 | $EC_CODE_128)
            #
            #  Unused partion is not sane.
            #  Recover device partition within capabilities of fsck.
            #
            otu_log $0 "Device $ALT_PART contains partition errors :: Initiating fsck recovery."
	          fsck -f -y $ALT_PART
            if [[ $? -eq 0 || $? -eq 1 ]]; then
                mount $ALT_PART /mnt/fs/unused_part  2>/dev/null
	              otu_log $0 "Recovery complete for device $ALT_PART ::  fsck repair return code = $?"
            else
	              otu_log $0 "Unable to repair $ALT_PART ::  fsck repair return code = $? ::  $ALT_PART is not mounted."
            fi
	      ;;

        *)
            #
            # Recovery procedure is not necessary
            #
            otu_log $0 "Partition recovery is NOT required for device $ALT_PART ."
        ;;
        esac
}

# If we are not Otu but /otu directory exists remove it (otu5000 to eotdrv2 conversion by manufacturing)
is_cotu_hw
HW_OTU=$?
is_otu_sw
SW_OTU=$?
[ "${HW_OTU}" == "0" ] && [ "${SW_OTU}" == "0" ] && [ -f /otu ] && rm -rf /otu

# Do the rest only if using otu
quit_if_not_using_otu

#
#  In OTU rescue mode only, check if unused partition
#  is corrupted and recover if possible.
#
if [[ "$(is_rescue)" == "yes" ]]; then
    otu_log $0 " . OTU is in rescue mode; inspecting $unused_prtn_device if partition is sane."
    inspect_repair_unused_prtn
fi
#

# Create /Otu directory
if [ ! -L /otu ] ;  then
    if [ -d /user/harddisk ] ; then
		mkdir -p /user/harddisk/otu
        ln -s /user/harddisk/otu /otu        
    elif [ -d /user/disk ] && [ "${HW_OTU}" == "0" ] && [ "${SW_OTU}" == "1" ] ; then
		mkdir -p /user/disk/otu
        ln -s /user/disk/otu /otu
    fi
else
	# Enforce link to otu to the harddisk if present
	if [ -d /user/harddisk ] && [ "$(readlink /otu)" != /user/harddisk/otu ] ; then
        rm /otu
        mkdir -p /user/harddisk/otu
        ln -sf /user/harddisk/otu /otu
	fi
	# Enforce /otu removal if harddisk is not present with otu hardware (do not work using flash)
	mountpoint /user/harddisk > /dev/null 2>&1
	HAS_NO_HARDDISK=$?
	if [ "${HAS_NO_HARDDISK}" == "1" ]  && [ "${HW_OTU}" == "1" ] && [ -h /otu ] ; then
	     rm -rf /otu
	fi
fi

# If the file debug exists we don't want to switch partition if Otu doesn't start
[ -f /acterna/storage/otu/debug ] && ! [ -f /otu/release/tmp/first_boot_after_upgrade.tmp ] && otu_confirm_start.sh

# In enhance security mode we have to check every boot that users have not been added during an upgrade
if [ "$(fw_printenv -n Enhanced_Security)" = "true" ] ; then
    bash /usr/lib/jdsu/scripts/update_user_list.sh "DEL" > /dev/null 2>&1
fi

# Log partition we are using in otu log
if [ -d /otu/log ] ; then
    CURRENT_DATE=$(date '+%Y-%m-%d %H:%M:%S.%3N')
    echo "${CURRENT_DATE} : Boot using partition ${CURRENT_PART}" >> /otu/log/boot.log
    if [[ "$(is_rescue)" == "yes" ]] ; then
        echo "${CURRENT_DATE} : Started in rescue mode" >> /otu/log/boot.log
    fi
fi

# Temporary : Create log file required for smartotu
touch /var/log/otu_query.log
touch /var/log/smart_otu.log
chown www-data:www-data /var/log/otu_query.log
chown www-data:www-data /var/log/smart_otu.log

# Temporary [as of 01/07/2024] : Make sure the /home/secuser folder is owned by secuser:secuser
id secuser
SECUSER_EXISTS=$?
[ ${SECUSER_EXISTS} -eq 0 ] && chown -R secuser:secuser /home/secuser

# Temporary [as of 25/09/2024] : Make sure the /otu/release/previous/cluster and /otu/release/previous/lxcluster
# folders are owned by secuser:user
if [ -d /otu/release/previous/cluster -a ${SECUSER_EXISTS} -eq 0 ]
then
    chown -R secuser:user /otu/release/previous/cluster
fi

if [ -d /otu/release/previous/lxcluster -a ${SECUSER_EXISTS} -eq 0 ]
then
    chown -R secuser:user /otu/release/previous/lxcluster
fi

exit 0
